@@ -3,6 +3,7 @@ from braintree.add_on_gateway import AddOnGateway
 from braintree.address import Address
 from braintree.address_gateway import AddressGateway
 from braintree.braintree_gateway import BraintreeGateway
+from braintree.client_token import ClientToken
 from braintree.configuration import Configuration
 from braintree.credit_card import CreditCard
 from braintree.credit_card_gateway import CreditCardGateway
@@ -35,6 +36,8 @@ from braintree.status_event import StatusEvent
 from braintree.transaction import Transaction
 from braintree.transaction_gateway import TransactionGateway
 from braintree.transaction_search import TransactionSearch
+from braintree.signature_service import SignatureService
+from braintree.disbursement import Disbursement
 from braintree.subscription_search import SubscriptionSearch
 from braintree.successful_result import SuccessfulResult
 from braintree.transaction_amounts import TransactionAmounts
