@@ -3,9 +3,13 @@ import hmac
 
 class Crypto:
     @staticmethod
-    def hmac_hash(secret_key, content):
+    def sha1_hmac_hash(secret_key, content):
         return hmac.new(hashlib.sha1(secret_key).digest(), content, hashlib.sha1).hexdigest()
 
+    @staticmethod
+    def sha256_hmac_hash(secret_key, content):
+        return hmac.new(hashlib.sha256(secret_key).digest(), content, hashlib.sha256).hexdigest()
+
     @staticmethod
     def secure_compare(left, right):
         if left == None or right == None:
